@@ -1,6 +1,7 @@
-from dataclasses import dataclass, field
+from dataclasses import field
 from typing import Optional
 
+from pydantic.dataclasses import dataclass
 from serde import deserialize
 
 from metaphor.common.filter import DatasetFilter
